@@ -39,6 +39,7 @@ from . import captcha
 from . import contentful
 from . import csfr
 from . import diag
+from . import export
 from . import loggly
 from . import opbeat
 from . import preflight
@@ -50,6 +51,7 @@ from .captcha import CaptchaPart
 from .contentful import Contentful
 from .csfr import CSFRPart, csfr_protect, csfr_ensure
 from .diag import DiagPart
+from .export import ExportPart
 from .loggly import LogglyHandler, LogglyPart
 from .opbeat import OpbeatPart
 from .preflight import PreflightPart
