@@ -745,16 +745,7 @@ class Account(base.Base, authenticable.Authenticable):
         meta = dict(self.meta)
         for role in self.roles_l:
             if join:
-                for key, value in appier.legacy.iteritems(role.meta_a):
-                    if key in meta:
-                        previous = meta[key]
-                        if not type(previous) == list:
-                            previous = [previous]
-                        if not value in previous:
-                            value = previous + [value]
-                        else:
-                            value = previous
-                    meta[key] = value
+                self._join_m(role.meta_a, meta)
             else:
                 meta.update(role.meta_a)
         return meta
@@ -808,11 +799,21 @@ class Account(base.Base, authenticable.Authenticable):
             owner = self.owner
         )
 
-    @property
-    def email_f(self):
-        if not self.email: return self.email
-        if not self.username: return self.email
-        return "%s <%s>" % (self.username, self.email)
+    def _join_m(self, origin, target):
+        for key, value in appier.legacy.iteritems(origin):
+            if key in target:
+                previous = target[key]
+                if isinstance(previous, dict):
+                    value = self._join_m(value, previous)
+                else:
+                    if not isinstance(previous, list):
+                        previous = [previous]
+                    if not value in previous:
+                        value = previous + [value]
+                    else:
+                        value = previous
+            target[key] = value
+        return target
 
     @appier.operation(name = "Touch Login")
     def touch_login_s(self):
@@ -890,23 +891,27 @@ class Account(base.Base, authenticable.Authenticable):
         self.save()
 
     @appier.operation(
-        name = "Add Role",
+        name = "Add Role(s)",
         parameters = (("Name", "name", str),)
     )
     def add_role_s(self, name):
-        _role = role.Role.get(name = name)
-        if _role in self.roles_l: return
-        self.roles_l.append(_role)
+        names = [name.strip() for name in name.strip().split(",")]
+        for name in names:
+            _role = role.Role.get(name = name)
+            if _role in self.roles_l: continue
+            self.roles_l.append(_role)
         self.save()
 
     @appier.operation(
-        name = "Remove Role",
+        name = "Remove Role(s)",
         parameters = (("Name", "name", str),)
     )
     def remove_role_s(self, name):
-        _role = role.Role.get(name = name)
-        if not _role in self.roles_l: return
-        self.roles_l.remove(_role)
+        names = [name.strip() for name in name.strip().split(",")]
+        for name in names:
+            _role = role.Role.get(name = name)
+            if not _role in self.roles_l: continue
+            self.roles_l.remove(_role)
         self.save()
 
     @appier.link(name = "View Avatar", devel = True)
@@ -934,6 +939,12 @@ class Account(base.Base, authenticable.Authenticable):
     def confirmed(self):
         return self.enabled
 
+    @property
+    def email_f(self):
+        if not self.email: return self.email
+        if not self.username: return self.email
+        return "%s <%s>" % (self.username, self.email)
+
     @property
     def roles_l(self):
         return self.roles
