@@ -281,12 +281,12 @@ class Base(appier.Model):
         logo = kwargs.pop("logo", logo)
         inline = kwargs.pop("inline", inline)
         engine = kwargs.pop("engine", None)
+        headers = kwargs.pop("headers", {})
         settings = dict(
             bulk = bulk,
             unsubscribe = unsubscribe,
             logo = logo
         )
-        headers = dict()
         if bulk: headers["Auto-Submitted"] = "auto-generated"
         if bulk: headers["Precedence"] = "bulk"
         if unsubscribe: headers["List-Unsubscribe"] = "<" + base_url + "/unsubscribe>"
@@ -350,6 +350,7 @@ class Base(appier.Model):
         file,
         callback,
         callback_header = None,
+        mime_type = None,
         strict = False,
         named = False,
         header = True,
@@ -361,6 +362,7 @@ class Base(appier.Model):
         is_unicode = appier.legacy.PYTHON_3
         csv_reader = cls._csv_read(
             file,
+            mime_type = mime_type,
             strict = strict,
             named = named,
             delimiter = delimiter,
@@ -388,6 +390,7 @@ class Base(appier.Model):
     def _csv_read(
         cls,
         file,
+        mime_type = None,
         strict = False,
         named = False,
         delimiter = ",",
@@ -396,7 +399,8 @@ class Base(appier.Model):
         encoding = "utf-8"
     ):
         is_unicode = appier.legacy.PYTHON_3
-        _file_name, mime_type, data = file
+        if appier.legacy.is_bytes(file): mime_type, data = mime_type, file
+        else: _file_name, mime_type, data = file
         is_csv = mime_type in ("text/csv", "application/vnd.ms-excel")
         if not is_csv and strict:
             raise appier.OperationalError(
@@ -421,10 +425,16 @@ class Base(appier.Model):
         file,
         callback,
         callback_header = None,
+        mime_type = None,
         strict = False,
         encoding = "utf-8"
     ):
-        json_data = cls._json_read(file, strict = strict, encoding = encoding)
+        json_data = cls._json_read(
+            file,
+            mime_type = mime_type,
+            strict = strict,
+            encoding = encoding
+        )
         header = appier.legacy.keys(json_data[0]) if json_data else []
         if callback_header: callback_header(header)
         for item in json_data: callback(item)
@@ -433,10 +443,12 @@ class Base(appier.Model):
     def _json_read(
         cls,
         file,
+        mime_type = None,
         strict = False,
         encoding = "utf-8"
     ):
-        _file_name, mime_type, data = file
+        if appier.legacy.is_bytes(file): mime_type, data = mime_type, file
+        else: _file_name, mime_type, data = file
         is_json = mime_type in ("text/json", "application/json")
         if not is_json and strict:
             raise appier.OperationalError(
@@ -487,8 +499,10 @@ class Base(appier.Model):
     def pre_create(self):
         appier.Model.pre_create(self)
 
-        if not hasattr(self, "enabled"): self.enabled = True
-        if not hasattr(self, "created"): self.created = int(time.time())
+        if not hasattr(self, "enabled") or self.enabled == None:
+            self.enabled = True
+        if not hasattr(self, "created") or self.created == None:
+            self.created = int(time.time())
         self.modified = int(time.time())
 
     def pre_update(self):
@@ -666,11 +680,31 @@ class Base(appier.Model):
         self = self.reload(rules = False)
         self.touch_s()
 
-    @appier.operation(name = "Datefix", devel = True)
-    def op_datefix_s(self):
+    @appier.operation(
+        name = "Datefix",
+        parameters = (("Force", "force", bool),),
+        devel = True
+    )
+    def op_datefix_s(self, force = False):
         self = self.reload(rules = False)
-        self.created = int(self.created)
-        self.modified = int(self.modified)
+        if force or (hasattr(self, "created") and not self.created == None):
+            self.created = int(self.created)
+        if force or (hasattr(self, "modified") and not self.modified == None):
+            self.modified = int(self.modified)
+        self.save(immutables_a = False)
+
+    @appier.operation(
+        name = "Dateset",
+        parameters = (("Force", "force", bool),),
+        level = 2,
+        devel = True
+    )
+    def op_dateset_s(self, force = False):
+        self = self.reload(rules = False)
+        if force or not hasattr(self, "created") or self.created == None:
+            self.created = int(time.time())
+        if force or not hasattr(self, "modified") or self.modified == None:
+            self.modified = int(time.time())
         self.save(immutables_a = False)
 
     @appier.operation(
