@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -136,7 +136,7 @@ class Settings(base.Base):
 
     def get_facebook_api(self):
         try: import facebook
-        except: return None
+        except Exception: return None
         if not self.facebook_token: return None
         redirect_url = self.owner.url_for("admin.oauth_facebook", absolute = True)
         access_token = self.facebook_token
@@ -149,7 +149,7 @@ class Settings(base.Base):
 
     def get_github_api(self):
         try: import github
-        except: return None
+        except Exception: return None
         if not self.github_token: return None
         redirect_url = self.owner.url_for("admin.oauth_github", absolute = True)
         access_token = self.github_token
@@ -162,7 +162,7 @@ class Settings(base.Base):
 
     def get_google_api(self):
         try: import google
-        except: return None
+        except Exception: return None
         if not self.google_token: return None
         cls = self.__class__
         redirect_url = self.owner.url_for("admin.oauth_google", absolute = True)
@@ -180,7 +180,7 @@ class Settings(base.Base):
 
     def get_live_api(self):
         try: import live
-        except: return None
+        except Exception: return None
         if not self.live_token: return None
         redirect_url = self.owner.url_for("admin.oauth_live", absolute = True)
         access_token = self.live_token
@@ -193,7 +193,7 @@ class Settings(base.Base):
 
     def get_twitter_api(self):
         try: import twitter
-        except: return None
+        except Exception: return None
         if not self.twitter_token: return None
         if not self.twitter_token_secret: return None
         redirect_url = self.owner.url_for("admin.oauth_twitter", absolute = True)
