@@ -226,11 +226,12 @@ class AdminPart(
             (("GET",), "/admin/oauth/deny", self.oauth_deny),
             (("GET", "POST"), "/admin/oauth/access_token", self.oauth_access_token, None, True),
             (("GET", "POST"), "/admin/oauth/login", self.oauth_login, None, True),
-            (("GET",), "/admin/operations/restart_app", self.restart_app),
-            (("GET",), "/admin/operations/build_index", self.build_index),
-            (("GET",), "/admin/operations/build_index_db", self.build_index_db),
-            (("GET",), "/admin/operations/test_email", self.test_email),
-            (("GET",), "/admin/operations/test_event", self.test_event),
+            (("GET", "POST"), "/admin/operations/restart_app", self.restart_app),
+            (("GET", "POST"), "/admin/operations/build_index", self.build_index),
+            (("GET", "POST"), "/admin/operations/build_index_db", self.build_index_db),
+            (("GET", "POST"), "/admin/operations/test_email", self.test_email),
+            (("GET", "POST"), "/admin/operations/test_event", self.test_event),
+            (("GET", "POST"), "/admin/operations/set_date", self.set_date),
             (("GET",), "/admin/sessions", self.list_sessions),
             (("GET",), "/admin/sessions/empty", self.empty_sessions),
             (("GET",), "/admin/sessions/me", self.show_session_me),
@@ -240,6 +241,7 @@ class AdminPart(
             (("GET",), "/admin/peers", self.list_peers),
             (("GET",), "/admin/counters", self.list_counters),
             (("GET",), "/admin/events.csv", self.list_events_csv),
+            (("GET",), "/admin/locale.csv", self.list_locales_csv),
             (("GET",), "/admin/locales/<int:id>/bundle.json", self.bundle_locale_json, None, True),
             (("GET",), "/admin/database", self.database),
             (("GET",), "/admin/database/export", self.database_export),
@@ -295,8 +297,8 @@ class AdminPart(
             (("GET", "POST"), "/api/admin/oauth/access_token", self.oauth_access_token_api, None, True),
             (("GET", "POST"), "/api/admin/oauth/login", self.oauth_login_api, None, True),
             (("GET",), "/api/admin/accounts/me", self.me_account_api, None, True),
-            (("GET",), "/api/admin/models/<str:model>", self.show_model_json, None, True),
-            (("GET",), "/api/admin/models/<str:model>/<str:_id>", self.show_entity_json, None, True)
+            (("GET",), "/api/admin/models/<str:model>", self.show_model_api, None, True),
+            (("GET",), "/api/admin/models/<str:model>/<str:_id>", self.show_entity_api, None, True)
         ]
 
     def models(self):
@@ -382,6 +384,7 @@ class AdminPart(
         self.add_operation(
             "test_email", "admin.test_email",
             description = "Send test email",
+            parameters = (("Email", "email", str, appier.conf("TEST_EMAIL", "")),),
             note = "Sending this email is going to use loaded SMTP configuration"
         )
         self.add_operation(
@@ -389,6 +392,13 @@ class AdminPart(
             description = "Trigger test event",
             note = "All handlers for the event are going to be triggered"
         )
+        self.add_operation(
+            "set_date", "admin.set_date",
+            description = "Set date (created & modified)",
+            note = "Updates the created and modified date values if their not set",
+            level = 3,
+            devel = True
+        )
 
     def unload_operations(self):
         self.remove_operation("restart_app")
@@ -396,6 +406,7 @@ class AdminPart(
         self.remove_operation("build_index_db")
         self.remove_operation("test_email")
         self.remove_operation("test_event")
+        self.remove_operation("set_date")
 
     def add_section(self, name):
         self._sections[name] = appier.OrderedDict()
@@ -422,6 +433,7 @@ class AdminPart(
         note = None,
         parameters = (),
         level = 1,
+        devel = False,
         args = [],
         kwargs = {}
     ):
@@ -433,6 +445,7 @@ class AdminPart(
             note = note,
             parameters = parameters,
             level = level,
+            devel = devel,
             args = args,
             kwargs = kwargs
         )
@@ -1102,7 +1115,7 @@ class AdminPart(
         )
 
     @appier.ensure(token = "admin", context = "admin")
-    def test_email(self):
+    def test_email(self, email = None):
         receiver = appier.conf("TEST_EMAIL", None)
         receiver = self.field("email", receiver)
         receiver = self.field("receiver", receiver)
@@ -1144,6 +1157,26 @@ class AdminPart(
             )
         )
 
+    @appier.ensure(token = "admin", context = "admin")
+    def set_date(self):
+        set_c = 0
+
+        for model_c in self._available(self.owner.models_r):
+            created_e = model_c.find(created = None, rules = False)
+            for entity in created_e: entity.op_dateset_s()
+            set_c += len(created_e)
+
+            modified_e = model_c.find(modified = None, rules = False)
+            for entity in modified_e: entity.op_dateset_s()
+            set_c += len(modified_e)
+
+        return self.redirect(
+            self.url_for(
+                "admin.operations",
+                message = "Date set in %d models" % set_c
+            )
+        )
+
     @appier.ensure(token = "admin.status", context = "admin")
     def list_sessions(self):
         return self.template(
@@ -1247,6 +1280,33 @@ class AdminPart(
         self.content_type("text/csv")
         return result
 
+    @appier.ensure(token = "admin", context = "admin")
+    def list_locales_csv(self):
+        object = appier.get_object(alias = True, find = True, limit = 0)
+        locales = self.admin_part._find_view(models.Locale, rules = False, **object)
+
+        header = ["name"]
+        locales_s = [header]
+
+        for locale in locales:
+            header.append(locale.locale)
+
+        names = set()
+
+        for locale in locales:
+            names.update(appier.legacy.keys(locale.data_j))
+
+        for name in sorted(names):
+            line = [name]
+            for locale in locales:
+                value = locale.data_j.get(name, "")
+                line.append(value)
+            locales_s.append(line)
+
+        result = appier.serialize_csv(locales_s, delimiter = ",")
+        self.content_type("text/csv")
+        return result
+
     @appier.ensure(token = "admin", context = "admin")
     def bundle_locale_json(self, id):
         name = self.field("name", None)
@@ -1507,12 +1567,15 @@ class AdminPart(
         parameters = definition.cast(parameters)
         parameters_kw = definition.cast(parameters, keyword = True)
 
+        # retrieves the initial kwargs to be sent to the find operation
+        # taking into account the operation definition
+        kwargs = definition.get("kwargs", None) or dict()
+
         # determines the filter information that is going to be passed
         # to the find operations and retrieves the associated entities
         # that are going to be the target for the operations, note that
         # if this is a global operation classes are used instead
-        if ids: kwargs = dict(_id = {"$in" : ids})
-        else: kwargs = dict()
+        if ids: kwargs.update(_id = {"$in" : ids})
         kwargs = self._apply_view(view, kwargs = kwargs, cls = model)
         if is_global: entities = (model,)
         else: entities = model.find_v(**kwargs)
@@ -2133,6 +2196,14 @@ class AdminPart(
         account = account_c.from_session(map = True)
         return account
 
+    @appier.ensure(context = "admin")
+    def show_model_api(self, model):
+        return self.show_model_json(model)
+
+    @appier.ensure(context = "admin")
+    def show_entity_api(self, model, _id):
+        return self.show_entity_json(model, _id)
+
     def socials(self):
         socials = []
         if self.has_facebook(): socials.append("facebook")
@@ -2154,13 +2225,15 @@ class AdminPart(
         value,
         anchors = False,
         blank = True,
+        escape = True,
         encoding = "utf-8"
     ):
         value = utils.MarkdownHTML.process_str(
             value,
             options = dict(
                 anchors = anchors,
-                blank = blank
+                blank = blank,
+                escape = escape
             ),
             encoding = encoding
         )
