@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -283,7 +283,7 @@ class Prismic(object):
                 *args,
                 **kwargs
             ) or []
-        except BaseException as exception:
+        except Exception as exception:
             self.logger.warning("Problem while accessing prismic: %s" % exception)
             return default
 
@@ -361,7 +361,7 @@ class Prismic(object):
                 *args,
                 **kwargs
             ) or []
-        except BaseException as exception:
+        except Exception as exception:
             self.logger.warning("Problem while accessing prismic: %s" % exception)
             return default
 
